==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/PartDesign/Gui/Resources/translations/PartDesign_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdPartDesignChamfer</name>
    <message>
      <location/>
      <source>Part</source>
      <translation>Tijelo</translation>
    </message>
    <message>
      <location/>
      <source>Chamfer...</source>
      <translation>Zarubi...</translation>
    </message>
    <message>
      <location/>
      <source>Chamfer the selected edges of a shape</source>
      <translation>Zarubi odabrane rubove, površine ili tijela</translation>
    </message>
  </context>
  <context>
    <name>CmdPartDesignFillet</name>
    <message>
      <location/>
      <source>PartDesign</source>
      <translation>Oblikovanje tijela</translation>
    </message>
    <message>
      <location/>
      <source>Fillet</source>
      <translation>Utisni</translation>
    </message>
    <message>
      <location/>
      <source>Make a fillet on an edge, face or body</source>
      <translation>Zaobli rub, površinu ili tijelo</translation>
    </message>
  </context>
  <context>
    <name>CmdPartDesignNewSketch</name>
    <message>
      <location/>
      <source>PartDesign</source>
      <translation>Oblikovanje tijela</translation>
    </message>
  </context>
  <context>
    <name>CmdPartDesignPad</name>
    <message>
      <location/>
      <source>PartDesign</source>
      <translation>Oblikovanje tijela</translation>
    </message>
    <message>
      <location/>
      <source>Pad</source>
      <translation>Izvučeni oblik</translation>
    </message>
    <message>
      <location/>
      <source>Pad a selected sketch</source>
      <translation>Izvuci odabranu skicu</translation>
    </message>
  </context>
  <context>
    <name>CmdPartDesignPocket</name>
    <message>
      <location/>
      <source>PartDesign</source>
      <translation>Oblikovanje tijela</translation>
    </message>
    <message>
      <location/>
      <source>Pocket</source>
      <translation>Džep</translation>
    </message>
    <message>
      <location/>
      <source>create a pocket with the selected sketch</source>
      <translation>stvoriti džep s odabranom skicom</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::ChamferWidget</name>
    <message>
      <location/>
      <source>Edges to chamfer</source>
      <translation>Rubove za zarubljivanje</translation>
    </message>
    <message>
      <location/>
      <source>Start distance</source>
      <translation>Početna udaljenost</translation>
    </message>
    <message>
      <location/>
      <source>End distance</source>
      <translation>Krajnja udaljenosti</translation>
    </message>
    <message>
      <location/>
      <source>Edge%1</source>
      <translation>Rub%1</translation>
    </message>
    <message>
      <location/>
      <source>Distance</source>
      <translation>Udaljenost</translation>
    </message>
    <message>
      <location/>
      <source>No shape selected</source>
      <translation>Nema odabranog oblika</translation>
    </message>
    <message>
      <location/>
      <source>No valid shape is selected.
Please select a valid shape in the drop-down box first.</source>
      <translation>Nije odabran vanljan oblik. Molimo odaberite valjan oblik u padajućem okviru.</translation>
    </message>
    <message>
      <location/>
      <source>No edge selected</source>
      <translation>Nema odabranih rubova</translation>
    </message>
    <message>
      <location/>
      <source>No edge entity is checked to chamfer.
Please check one or more edge entities first.</source>
      <translation>Nije odabran ni jedan rub. Molimo prvo odaberite jedan ili više rubova.</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskChamfer</name>
    <message>
      <location/>
      <source>Chamfer Edges</source>
      <translation>Zarubi stranice</translation>
    </message>
    <message>
      <location/>
      <source>Shape</source>
      <translation>Oblik</translation>
    </message>
    <message>
      <location/>
      <source>Selected shape:</source>
      <translation>Odabrani oblik:</translation>
    </message>
    <message>
      <location/>
      <source>No selection</source>
      <translation>Nema odabira</translation>
    </message>
    <message>
      <location/>
      <source>Chamfer Parameter</source>
      <translation>Parametar zarubljenja</translation>
    </message>
    <message>
      <location/>
      <source>All</source>
      <translation>Sve</translation>
    </message>
    <message>
      <location/>
      <source>None</source>
      <translation>Nijedan</translation>
    </message>
    <message>
      <location/>
      <source>Chamfer type:</source>
      <translation>Oluk tip:</translation>
    </message>
    <message>
      <location/>
      <source>Constant Distance</source>
      <translation>Konstantna Udaljenost</translation>
    </message>
    <message>
      <location/>
      <source>Variable Distance</source>
      <translation>Promjenjiva udaljenost</translation>
    </message>
    <message>
      <location/>
      <source>Distance:</source>
      <translation>Udaljenost:</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskPadParameters</name>
    <message>
      <location/>
      <source>Form</source>
      <translation>Obrazac</translation>
    </message>
    <message>
      <location/>
      <source>Display mode:</source>
      <translation>Prikaz:</translation>
    </message>
    <message>
      <location/>
      <source>Plot mode:</source>
      <translation>Način crtanja:</translation>
    </message>
    <message>
      <location/>
      <source>Point size:</source>
      <translation>Veličina točke:</translation>
    </message>
    <message>
      <location/>
      <source>Line width:</source>
      <translation>Širina linije:</translation>
    </message>
    <message>
      <location/>
      <source>Transparency:</source>
      <translation>Prozirnost:</translation>
    </message>
    <message>
      <location/>
      <source>TaskPadParameters</source>
      <translation>TaskPadParameters</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location/>
      <source>Wrong selection</source>
      <translation>Pogrešan odabir</translation>
    </message>
    <message>
      <location/>
      <source>Select a sketch or 2D object.</source>
      <translation>Odaberite skicu ili 2D objekt.</translation>
    </message>
    <message>
      <location/>
      <source>The shape of the selected object is empty.</source>
      <translation>Oblik odabranog objekta je prazan.</translation>
    </message>
    <message>
      <location/>
      <source>The shape of the selected object is not a wire.</source>
      <translation>Oblik odabranog objekta nije žica.</translation>
    </message>
    <message>
      <location/>
      <source>Select an edge, face or body. Only one body is allowed.</source>
      <translation>Odaberite rub, plohu ili tijelo. Samo jedno tijelo je dozvoljeno.</translation>
    </message>
    <message>
      <location/>
      <source>Wrong object type</source>
      <translation>Pogrešan tip objekta</translation>
    </message>
    <message>
      <location/>
      <source>Fillet works only on parts</source>
      <translation>Rubove možete zaobliti samo na tijelima</translation>
    </message>
    <message>
      <location/>
      <source>No Support</source>
      <translation>Bez podrške</translation>
    </message>
    <message>
      <location/>
      <source>The sketch has to have a support for the pocket feature.
Create the sketch on a face.</source>
      <translation>Skica mora imati podršku za udubljenje. Napravite skicu na površini.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location/>
      <source>Part Design</source>
      <translation>Oblikovanje tijela</translation>
    </message>
  </context>
</TS>

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/PartDesign/Gui/Resources/translations/PartDesign_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdPartDesignChamfer</name>
    <message>
      <location filename="../../Command.cpp" line="+378"/>
      <source>Part</source>
      <translation>Tijelo</translation>
    </message>
    <message>
      <source>Chamfer...</source>
      <translation>Zarubi...</translation>
    </message>
    <message>
      <source>Chamfer the selected edges of a shape</source>
      <translation>Zarubi odabrane rubove, površine ili tijela</translation>
    </message>
  </context>
  <context>
    <name>CmdPartDesignFillet</name>
    <message>
      <source>PartDesign</source>
      <translation>Oblikovanje tijela</translation>
    </message>
    <message>
      <source>Fillet</source>
      <translation>Utisni</translation>
    </message>
    <message>
      <source>Make a fillet on an edge, face or body</source>
      <translation>Zaobli rub, površinu ili tijelo</translation>
    </message>
  </context>
  <context>
    <name>CmdPartDesignPad</name>
    <message>
      <source>PartDesign</source>
      <translation>Oblikovanje tijela</translation>
    </message>
    <message>
      <source>Pad</source>
      <translation>Izvučeni oblik</translation>
    </message>
    <message>
      <source>Pad a selected sketch</source>
      <translation>Izvuci odabranu skicu</translation>
    </message>
  </context>
  <context>
    <name>CmdPartDesignPocket</name>
    <message>
      <source>PartDesign</source>
      <translation>Oblikovanje tijela</translation>
    </message>
    <message>
      <source>Pocket</source>
      <translation>Džep</translation>
    </message>
    <message>
      <source>create a pocket with the selected sketch</source>
      <translation>stvoriti džep s odabranom skicom</translation>
    </message>
  </context>
  <context>
    <name>CmdPartDesignRevolution</name>
    <message>
      <source>PartDesign</source>
      <translation>Oblikovanje tijela</translation>
    </message>
    <message>
      <source>Revolution</source>
      <translation>Obrtaj</translation>
    </message>
    <message>
      <source>Revolve a selected sketch</source>
      <translation>Kreiraj tijelo obrtanjem skice</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="+39"/>
      <source>Face tools</source>
      <translation>Alati plohe</translation>
    </message>
    <message>
      <source>Sketch tools</source>
      <translation>Alati skice</translation>
    </message>
    <message>
      <source>Create Geometry</source>
      <translation>Napravi geometriju</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::ChamferWidget</name>
    <message>
      <location filename="../../TaskChamfer.cpp" line="+182"/>
      <source>Edges to chamfer</source>
      <translation>Rubove za zarubljivanje</translation>
    </message>
    <message>
      <source>Start distance</source>
      <translation>Početna udaljenost</translation>
    </message>
    <message>
      <source>End distance</source>
      <translation>Krajnja udaljenosti</translation>
    </message>
    <message>
      <source>Edge%1</source>
      <translation>Rub%1</translation>
    </message>
    <message>
      <source>Distance</source>
      <translation>Udaljenost</translation>
    </message>
    <message>
      <source>No shape selected</source>
      <translation>Nema odabranog oblika</translation>
    </message>
    <message>
      <source>No valid shape is selected.
Please select a valid shape in the drop-down box first.</source>
      <translation>Nije odabran vanljan oblik. Molimo odaberite valjan oblik u padajućem okviru.</translation>
    </message>
    <message>
      <source>No edge selected</source>
      <translation>Nema odabranih rubova</translation>
    </message>
    <message>
      <source>No edge entity is checked to chamfer.
Please check one or more edge entities first.</source>
      <translation>Nije odabran ni jedan rub. Molimo prvo odaberite jedan ili više rubova.</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskChamfer</name>
    <message>
      <location filename="../../TaskChamfer.ui" line="+14"/>
      <source>Chamfer Edges</source>
      <translation>Zarubi stranice</translation>
    </message>
    <message>
      <source>Shape</source>
      <translation>Oblik</translation>
    </message>
    <message>
      <source>Selected shape:</source>
      <translation>Odabrani oblik:</translation>
    </message>
    <message>
      <source>No selection</source>
      <translation>Nema odabira</translation>
    </message>
    <message>
      <source>Chamfer Parameter</source>
      <translation>Parametar zarubljenja</translation>
    </message>
    <message>
      <source>All</source>
      <translation>Sve</translation>
    </message>
    <message>
      <source>None</source>
      <translation>Nijedan</translation>
    </message>
    <message>
      <source>Chamfer type:</source>
      <translation>Oluk tip:</translation>
    </message>
    <message>
      <source>Constant Distance</source>
      <translation>Konstantna Udaljenost</translation>
    </message>
    <message>
      <source>Variable Distance</source>
      <translation>Promjenjiva udaljenost</translation>
    </message>
    <message>
      <source>Distance:</source>
      <translation>Udaljenost:</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskDlgPadParameters</name>
    <message>
      <location filename="../../TaskPadParameters.cpp" line="+189"/>
      <source>Input error</source>
      <translation>Input error</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskFilletParameters</name>
    <message>
      <location filename="../../TaskFilletParameters.ui" line="+14"/>
      <source>Form</source>
      <translation>Obrazac</translation>
    </message>
    <message>
      <source>Radius:</source>
      <translation>Polumjer:</translation>
    </message>
    <message>
      <location filename="../../TaskFilletParameters.cpp" line="+51"/>
      <source>Fillet parameters</source>
      <translation>Fillet parameters</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskHoleParameters</name>
    <message>
      <location filename="../../TaskHoleParameters.ui" line="+14"/>
      <source>Form</source>
      <translation>Obrazac</translation>
    </message>
    <message>
      <source>Type:</source>
      <translation>Vrsta:</translation>
    </message>
    <message>
      <source>Dimension</source>
      <translation>Dimenzija</translation>
    </message>
    <message>
      <source>Up to last</source>
      <translation>Do posljednjeg</translation>
    </message>
    <message>
      <source>Up to first</source>
      <translation>Do prve</translation>
    </message>
    <message>
      <source>Size:</source>
      <translation>Veličina:</translation>
    </message>
    <message>
      <location filename="../../TaskHoleParameters.cpp" line="+47"/>
      <source>TaskHoleParameters</source>
      <translation>TaskHoleParametri</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskPadParameters</name>
    <message>
      <location filename="../../TaskPadParameters.ui" line="+14"/>
      <source>Form</source>
      <translation>Obrazac</translation>
    </message>
    <message>
      <source>Type:</source>
      <translation>Vrsta:</translation>
    </message>
    <message>
      <source>Dimension</source>
      <translation>Dimenzija</translation>
    </message>
    <message>
      <source>Length:</source>
      <translation>Duljina:</translation>
    </message>
    <message>
      <source>Mirrored extent</source>
      <translation>Mjera zrcaljenja</translation>
    </message>
    <message>
      <source>Reversed</source>
      <translation>Obrnuti</translation>
    </message>
    <message>
      <source>Display mode:</source>
      <translation>Prikaz:</translation>
    </message>
    <message>
      <source>Plot mode:</source>
      <translation>Način crtanja:</translation>
    </message>
    <message>
      <source>Point size:</source>
      <translation>Veličina točke:</translation>
    </message>
    <message>
      <source>Line width:</source>
      <translation>Širina linije:</translation>
    </message>
    <message>
      <source>Transparency:</source>
      <translation>Prozirnost:</translation>
    </message>
    <message>
      <source>TaskPadParameters</source>
      <translation>TaskPadParameters</translation>
    </message>
    <message>
      <location filename="../../TaskPadParameters.cpp" line="-137"/>
      <source>Pad parameters</source>
      <translation>Parametri izvučenog oblika</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskPatternRectangularParameters</name>
    <message>
      <location filename="../../TaskPatternRectangularParameters.ui" line="+14"/>
      <source>Form</source>
      <translation>Obrazac</translation>
    </message>
    <message>
      <source>Spacing1:</source>
      <translation>Razmak1:</translation>
    </message>
    <message>
      <source>Number1:</source>
      <translation>Broj1:</translation>
    </message>
    <message>
      <source>Second extend</source>
      <translation>Drugi kraj</translation>
    </message>
    <message>
      <source>Spacing2:</source>
      <translation>Razmak2:</translation>
    </message>
    <message>
      <source>Number2:</source>
      <translation>Broj2:</translation>
    </message>
    <message>
      <location filename="../../TaskPatternRectangularParameters.cpp" line="+47"/>
      <source>TaskPatternRectangularParameters</source>
      <translation>TaskPatternRectangularParametri</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskPocketParameters</name>
    <message>
      <location filename="../../TaskPocketParameters.ui" line="+14"/>
      <source>Form</source>
      <translation>Obrazac</translation>
    </message>
    <message>
      <source>Type:</source>
      <translation>Vrsta:</translation>
    </message>
    <message>
      <source>Dimension</source>
      <translation>Dimenzija</translation>
    </message>
    <message>
      <source>Length</source>
      <translation>Length</translation>
    </message>
    <message>
      <location filename="../../TaskPocketParameters.cpp" line="+51"/>
      <source>Pocket parameters</source>
      <translation>Pocket parameters</translation>
    </message>
  </context>
  <context>
    <name>PartDesignGui::TaskRevolutionParameters</name>
    <message>
      <location filename="../../TaskRevolutionParameters.ui" line="+14"/>
      <source>Form</source>
      <translation>Obrazac</translation>
    </message>
    <message>
      <source>Axis:</source>
      <translation>Os:</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Vertical</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Horizontal</translation>
    </message>
    <message>
      <source>Angle:</source>
      <translation>Kut:</translation>
    </message>
    <message>
      <location filename="../../TaskRevolutionParameters.cpp" line="+51"/>
      <source>Revolution parameters</source>
      <translation>Revolution parameters</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="-144"/>
      <source>Wrong selection</source>
      <translation>Pogrešan odabir</translation>
    </message>
    <message>
      <source>Select a sketch or 2D object.</source>
      <translation>Odaberite skicu ili 2D objekt.</translation>
    </message>
    <message>
      <source>The shape of the selected object is empty.</source>
      <translation>Oblik odabranog objekta je prazan.</translation>
    </message>
    <message>
      <source>The shape of the selected object is not a wire.</source>
      <translation>Oblik odabranog objekta nije žica.</translation>
    </message>
    <message>
      <source>Select an edge, face or body. Only one body is allowed.</source>
      <translation>Odaberite rub, plohu ili tijelo. Samo jedno tijelo je dozvoljeno.</translation>
    </message>
    <message>
      <source>Wrong object type</source>
      <translation>Pogrešan tip objekta</translation>
    </message>
    <message>
      <source>Fillet works only on parts</source>
      <translation>Rubove možete zaobliti samo na tijelima</translation>
    </message>
    <message>
      <source>No Support</source>
      <translation>Bez podrške</translation>
    </message>
    <message>
      <source>The sketch has to have a support for the pocket feature.
Create the sketch on a face.</source>
      <translation>Skica mora imati podršku za udubljenje. Napravite skicu na površini.</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPad.cpp" line="+60"/>
      <source>Edit pad</source>
      <translation>Uredi izvučeni oblik</translation>
    </message>
    <message>
      <location filename="../../ViewProviderFillet.cpp" line="+54"/>
      <source>Edit pocket</source>
      <translation>Edit pocket</translation>
    </message>
    <message>
      <source>A dialog is already open in the task panel</source>
      <translation>Dijalog je već otvoren u ploči zadataka</translation>
    </message>
    <message>
      <source>Do you want to close this dialog?</source>
      <translation>Želite li zatvoriti ovaj dijalog?</translation>
    </message>
    <message>
      <location filename="../../ViewProviderRevolution.cpp" line="-18"/>
      <source>Edit revolution</source>
      <translation>Edit revolution</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="-3"/>
      <source>Part Design</source>
      <translation>Oblikovanje tijela</translation>
    </message>
  </context>
</TS>
